==> skypager-project-2.2.1.tgz: package/lib/helpers/action.js <==
'use strict';

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _helper = require('./helper');

var _helper2 = _interopRequireDefault(_helper);

var _registry = require('../registry');

var _registry2 = _interopRequireDefault(_registry);

var _action = require('./definitions/action');

var _util = require('../util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Action = (function (_Helper) {
  (0, _inherits3.default)(Action, _Helper);

  function Action() {
    (0, _classCallCheck3.default)(this, Action);
    return (0, _possibleConstructorReturn3.default)(this, (0, _getPrototypeOf2.default)(Action).apply(this, arguments));
  }

  (0, _createClass3.default)(Action, [{
    key: 'helperClass',
    get: function get() {
      return Action;
    }
  }, {
    key: 'definitionClass',
    get: function get() {
      return _action.ActionDefinition;
    }
  }], [{
    key: 'registryInterface',
    value: function registryInterface(registry) {
      return {
        actionsForCLI: {
          get: function get() {
            return registry.query(function (action) {
              return _util.dotpath.get(action, 'definition.interfaces.cli');
            });
          }
        }
      };
    }
  }]);
  return Action;
})(_helper2.default);

Action.DSL = _action.DSL;
Action.Definition = _action.ActionDefinition;
Action.apiMethods = _action.ActionDefinition.apiMethods;

module.exports = Action;

==> skypager-project-2.33.0.tgz: package/lib/helpers/action.js <==
'use strict';

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _helper = require('./helper');

var _helper2 = _interopRequireDefault(_helper);

var _registry = require('../registry');

var _registry2 = _interopRequireDefault(_registry);

var _action = require('./definitions/action');

var _util = require('../util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Action = (function (_Helper) {
  (0, _inherits3.default)(Action, _Helper);

  function Action() {
    (0, _classCallCheck3.default)(this, Action);
    return (0, _possibleConstructorReturn3.default)(this, (0, _getPrototypeOf2.default)(Action).apply(this, arguments));
  }

  (0, _createClass3.default)(Action, [{
    key: 'attachCLI',

    /**
     * Configures a CLI utility such as commander to be able to expose
     * this action over a CLI interface.  Any additional context passed
     * from the CLI will be included, and we will make sure the project
     * is set
    */
    value: function attachCLI(commander, dispatchFn) {
      var context = arguments.length <= 2 || arguments[2] === undefined ? {} : arguments[2];

      context.project = context.project || this.project;

      if (this.get('definition.interfaces.cli')) {
        this.interfaces.cli.call(this, commander, dispatchFn);
      }
    }
  }, {
    key: 'interfaces',
    get: function get() {
      return this.definition.interfaces;
    }
  }, {
    key: 'helperClass',
    get: function get() {
      return Action;
    }
  }, {
    key: 'definitionClass',
    get: function get() {
      return _action.ActionDefinition;
    }
  }], [{
    key: 'registryInterface',
    value: function registryInterface(registry) {
      return {
        actionsForCLI: {
          get: function get() {
            return registry.query(function (action) {
              return action.get('definition.interfaces.cli');
            });
          }
        }
      };
    }
  }]);
  return Action;
})(_helper2.default);

Action.DSL = _action.DSL;
Action.Definition = _action.ActionDefinition;
Action.apiMethods = _action.ActionDefinition.apiMethods;

module.exports = Action;
